@@ -18,27 +18,22 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Check Command Module."""
-from __future__ import annotations
 
-import logging
-import os
+from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-import click
-
 from molecule import util
+from molecule.click_cfg import click_command_ex, common_options
 from molecule.command import base
 
 
 if TYPE_CHECKING:
+    import click
+
     from molecule.types import CommandArgs, MoleculeArgs
 
 
-LOG = logging.getLogger(__name__)
-MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
-
-
 class Check(base.Base):
     """Check Command Class."""
 
@@ -52,52 +47,28 @@ class Check(base.Base):
             self._config.provisioner.check()
 
 
-@base.click_command_ex()
-@click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    multiple=True,
-    default=[base.MOLECULE_DEFAULT_SCENARIO_NAME],
-    help=f"Name of the scenario to target. May be specified multiple times. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
-@click.option(
-    "--all/--no-all",
-    "__all",
-    default=False,
-    help="Check all scenarios. Default is False.",
-)
-@click.option(
-    "--exclude",
-    "-e",
-    multiple=True,
-    help="Name of the scenario to exclude from running. May be specified multiple times.",
-)
-@click.option(
-    "--parallel/--no-parallel",
-    default=MOLECULE_PARALLEL,
-    help="Enable or disable parallel mode. Default is disabled.",
-)
-def check(  # pragma: no cover
-    ctx: click.Context,
-    scenario_name: list[str] | None,
-    exclude: list[str],
-    __all: bool,  # noqa: FBT001
-    *,
-    parallel: bool,
-) -> None:
+@click_command_ex()
+@common_options("parallel")
+def check(ctx: click.Context) -> None:  # pragma: no cover
     """Use the provisioner to perform a Dry-Run (destroy, dependency, create, prepare, converge).
 
     Args:
         ctx: Click context object holding commandline arguments.
-        scenario_name: Name of the scenario to target.
-        exclude: Name of the scenarios to avoid targeting.
-        __all: Whether molecule should target scenario_name or all scenarios.
-        parallel: Whether the scenario(s) should be run in parallel.
     """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"parallel": parallel, "subcommand": subcommand}
+    parallel = ctx.params["parallel"]
+    command_args: CommandArgs = {
+        "parallel": parallel,
+        "report": ctx.params["report"],
+        "shared_inventory": ctx.params["shared_inventory"],
+        "shared_state": ctx.params["shared_state"],
+        "subcommand": subcommand,
+    }
+
+    __all = ctx.params["all"]
+    exclude = ctx.params["exclude"]
+    scenario_name = ctx.params["scenario_name"]
 
     if __all:
         scenario_name = None
