@@ -21,23 +21,20 @@
 
 from __future__ import annotations
 
-import logging
 import re
 
 from typing import TYPE_CHECKING
 
-import click
-
+from molecule.click_cfg import click_command_ex, common_options
 from molecule.command import base
 from molecule.exceptions import ScenarioFailureError
 from molecule.text import strip_ansi_escape
 
 
 if TYPE_CHECKING:
-    from molecule.types import CommandArgs, MoleculeArgs
+    import click
 
-
-LOG = logging.getLogger(__name__)
+    from molecule.types import CommandArgs
 
 
 class Idempotence(base.Base):
@@ -66,7 +63,7 @@ class Idempotence(base.Base):
             idempotent = self._is_idempotent(output)
             if idempotent:
                 msg = "Idempotence completed successfully."
-                LOG.info(msg)
+                self._log.info(msg)
             else:
                 details = "\n".join(self._non_idempotent_tasks(output))
                 msg = f"Idempotence test failed because of the following tasks:\n{details}"
@@ -120,42 +117,30 @@ class Idempotence(base.Base):
         return res
 
 
-@base.click_command_ex()
-@click.pass_context
-@base.click_command_options
-@click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
-def idempotence(  # noqa: PLR0913
-    ctx: click.Context,
-    scenario_name: list[str] | None,
-    exclude: list[str],
-    __all: bool,  # noqa: FBT001
-    *,
-    ansible_args: tuple[str, ...],
-    report: bool,
-    shared_inventory: bool,
-) -> None:  # pragma: no cover
+@click_command_ex()
+@common_options("ansible_args")
+def idempotence(ctx: click.Context) -> None:  # pragma: no cover
     """Use the provisioner to configure the instances.
 
     After parse the output to determine idempotence.
 
-    \f
     Args:
         ctx: Click context object holding commandline arguments.
-        scenario_name: Name of the scenario to target.
-        exclude: Name of the scenarios to avoid targeting.
-        __all: Whether molecule should target scenario_name or all scenarios.
-        ansible_args: Arguments to forward to Ansible.
-        report: Whether to show an after-run summary report.
-        shared_inventory: Whether the inventory should be shared between scenarios.
-    """  # noqa: D301
-    args: MoleculeArgs = ctx.obj.get("args")
+    """
+    args = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {
+        "report": ctx.params["report"],
+        "shared_inventory": ctx.params["shared_inventory"],
+        "shared_state": ctx.params["shared_state"],
         "subcommand": subcommand,
-        "report": report,
-        "shared_inventory": shared_inventory,
     }
 
+    __all = ctx.params["all"]
+    ansible_args = ctx.params["ansible_args"]
+    exclude = ctx.params["exclude"]
+    scenario_name = ctx.params["scenario_name"]
+
     if __all:
         scenario_name = None
 
