@@ -22,7 +22,6 @@
 from __future__ import annotations
 
 import copy
-import logging
 import os
 import warnings
 
@@ -32,7 +31,7 @@ from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
 
-from molecule import api, interpolation, platforms, scenario, state, util
+from molecule import api, interpolation, logger, platforms, scenario, state, util
 from molecule.app import get_app
 from molecule.data import __file__ as data_module
 from molecule.dependency import ansible_galaxy, shell
@@ -55,7 +54,6 @@ if TYPE_CHECKING:
     from molecule.verifier.base import Verifier
 
 
-LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL: bool = boolean(os.environ.get("MOLECULE_PARALLEL", ""))
 MOLECULE_DEBUG: bool = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
 MOLECULE_VERBOSITY: int = int(os.environ.get("MOLECULE_VERBOSITY", "0"))
@@ -166,6 +164,15 @@ class Config:
         """
         return self.command_args.get("shared_inventory", False)
 
+    @property
+    def shared_data(self) -> bool:
+        """Should molecule share ephemeral data.
+
+        Returns:
+            Whether molecule should share ephemeral data.
+        """
+        return self.command_args.get("shared_state", False)
+
     @property
     def platform_name(self) -> str | None:
         """Configured platform.
@@ -278,7 +285,7 @@ class Config:
 
         important_keys = {"name", "namespace"}
         if missing_keys := important_keys.difference(galaxy_data.keys()):
-            LOG.warning(
+            self._log.warning(
                 "The detected galaxy.yml file (%s) is invalid, missing mandatory field %s",
                 galaxy_file,
                 util.oxford_comma(missing_keys),
@@ -392,6 +399,15 @@ class Config:
         """
         return scenario.Scenario(self)
 
+    @property
+    def _log(self) -> logger.ScenarioLoggerAdapter:
+        """Get a scenario logger with config step context.
+
+        Returns:
+            A scenario logger adapter with current scenario and step context.
+        """
+        return logger.get_scenario_logger(__name__, self.scenario.name, "config")
+
     @cached_property
     def state(self) -> State:
         """Molecule state object.
@@ -399,21 +415,22 @@ class Config:
         Returns:
             A molecule State instance.
         """
-        myState = state.State(self)  # noqa: N806
+        my_state = state.State(self)
+
         # look at state file for molecule.yml date modified and warn if they do not match
         if self.molecule_file and os.path.isfile(self.molecule_file):  # noqa: PTH113
             modTime = os.path.getmtime(self.molecule_file)  # noqa: PTH204, N806
-            if myState.molecule_yml_date_modified is None:
-                myState.change_state("molecule_yml_date_modified", modTime)
-            elif myState.molecule_yml_date_modified != modTime:
-                LOG.warning(
+            if my_state.molecule_yml_date_modified is None:
+                my_state.change_state("molecule_yml_date_modified", modTime)
+            elif my_state.molecule_yml_date_modified != modTime:
+                self._log.warning(
                     "The scenario config file ('%s') has been modified since the scenario was created. "
                     "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "
                     "'molecule reset' to clear current configuration.",
                     self.molecule_file,
                 )
 
-        return state.State(self)
+        return state.SharedState(self) if self.shared_data else state.State(self)
 
     @cached_property
     def verifier(self) -> Verifier:
@@ -468,7 +485,7 @@ class Config:
                 f"has changed and now defines '{driver_from_scenario}'. "
                 "To change drivers, run 'molecule destroy' for converged scenarios or 'molecule reset' otherwise."
             )
-            LOG.warning(msg)
+            self._log.warning(msg)
 
         return driver_name
 
@@ -660,8 +677,12 @@ class Config:
         Raises:
             MoleculeError: when config file fails to validate.
         """
+        # Use scenario logger with hardcoded values since scenario property isn't available yet
+        scenario_name = self.config["scenario"]["name"]
+        validation_log = logger.get_scenario_logger(__name__, scenario_name, "validate")
+
         msg = f"Validating schema {self.molecule_file}."
-        LOG.debug(msg)
+        validation_log.debug(msg)
 
         errors = schema_v3.validate(self.config)
         if errors:
