@@ -18,9 +18,8 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Shell Dependency Module."""
-from __future__ import annotations
 
-import logging
+from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
@@ -33,9 +32,6 @@ if TYPE_CHECKING:
     from molecule.config import Config
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Shell(base.Base):
     """``Shell`` is an alternate dependency manager.
 
@@ -115,7 +111,7 @@ class Shell(base.Base):
         """
         if not self.enabled:
             msg = "Skipping, dependency is disabled."
-            LOG.warning(msg)
+            self._log.warning(msg)
             return
         super().execute()
 
