@@ -21,8 +21,6 @@
 
 from __future__ import annotations
 
-import logging
-
 from pathlib import Path
 from typing import TYPE_CHECKING
 
@@ -37,9 +35,6 @@ if TYPE_CHECKING:
     from molecule.config import Config
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Delegated(Driver):
     r"""The class responsible for managing default instances.
 
