@@ -18,9 +18,8 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """PLatforms Module."""
-from __future__ import annotations
 
-import logging
+from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
@@ -32,9 +31,6 @@ if TYPE_CHECKING:
     from molecule.types import PlatformData
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Platforms:
     """Platforms define the instances to be tested, and the groups to which the instances belong.
 
