@@ -18,16 +18,20 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Ansible-Playbook Provisioner Module."""
+
 from __future__ import annotations
 
-import logging
 import shlex
+import subprocess
 import warnings
 
 from typing import TYPE_CHECKING
 
-from molecule import util
+from rich.markup import escape
+
+from molecule import logger, util
 from molecule.api import MoleculeRuntimeWarning
+from molecule.exceptions import ScenarioFailureError
 from molecule.types import ScenarioResult
 
 
@@ -35,9 +39,6 @@ if TYPE_CHECKING:
     from molecule.config import Config
 
 
-LOG = logging.getLogger(__name__)
-
-
 class AnsiblePlaybook:
     """Provisioner Playbook."""
 
@@ -69,8 +70,24 @@ class AnsiblePlaybook:
         elif self._config.provisioner:
             self._env = self._config.provisioner.env
 
+    @property
+    def _log(self) -> logger.ScenarioLoggerAdapter:
+        """Get a fresh scenario logger with current context.
+
+        Returns:
+            A scenario logger adapter with current scenario and step context.
+        """
+        # Get step context from the current action being executed
+        step_name = getattr(self._config, "action", "provisioner")
+        return logger.get_scenario_logger(__name__, self._config.scenario.name, step_name)
+
     def bake(self) -> None:
-        """Bake an ``ansible-playbook`` command so it's ready to execute."""
+        """Bake ``ansible-playbook`` or ``navigator run`` command so it's ready to execute.
+
+        Raises:
+            ValueError: when backend is incorrect.
+            RuntimeError: when ansible-playbook or ansible-navigator is not available.
+        """
         if not self._playbook:
             return
 
@@ -99,28 +116,62 @@ class AnsiblePlaybook:
             else:
                 ansible_args = []
 
-            self._ansible_command = [
-                "ansible-playbook",
-                *util.dict2args(options),
-                *util.bool2args(verbose_flag),
-                *ansible_args,
-                self._playbook,  # must always go last
-            ]
+            backend = self._config.executor
+
+            if backend:
+                try:
+                    result = subprocess.run(
+                        [backend, "--version"],
+                        capture_output=True,
+                        text=True,
+                        check=True,
+                    )
+                    self._log.info("%s version: %s", backend, result.stdout.strip())
+                except subprocess.CalledProcessError as exc:
+                    msg = f"{backend} is not available. Please ensure that it is installed."
+                    raise RuntimeError(msg) from exc
+
+            if backend == "ansible-playbook":
+                self._ansible_command = [
+                    "ansible-playbook",
+                    *util.dict2args(options),
+                    *util.bool2args(verbose_flag),
+                    *ansible_args,
+                    self._playbook,  # must always go last
+                ]
+
+            elif backend == "ansible-navigator":
+                self._ansible_command = [
+                    "ansible-navigator",
+                    "run",
+                    self._playbook,
+                    "--mode",
+                    "stdout",
+                    *util.dict2args(options),
+                    *util.bool2args(verbose_flag),
+                    *ansible_args,
+                ]
+            else:
+                msg = f"Unsupported backend: {backend}"
+                raise ValueError(msg)
 
     def execute(self, action_args: list[str] | None = None) -> str:  # noqa: ARG002
-        """Execute ``ansible-playbook``.
+        """Execute ``ansible-playbook`` or ``ansible-navigator run``.
 
         Args:
             action_args: Arguments to forward to the action. Unused.
 
         Returns:
-            Output from ansible-playbook.
+            Output from ansible-playbook or ansible-navigator.
+
+        Raises:
+            ScenarioFailureError: when Ansible returns nonzero code.
         """
         if not self._ansible_command:
             self.bake()
 
         if not self._playbook:
-            LOG.warning("Skipping, %s action has no playbook.", self._config.action)
+            self._log.warning("Skipping, %s action has no playbook.", self._config.action)
             self._config.scenario.results.append(
                 ScenarioResult(subcommand=self._config.action, state="SKIPPED"),
             )
@@ -142,11 +193,10 @@ class AnsiblePlaybook:
                 ScenarioResult(subcommand=self._config.action, state="FAILED"),
             )
 
-            from rich.markup import escape
-
-            util.sysexit_with_message(
-                f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]",
-                result.returncode,
+            msg = f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]"
+            raise ScenarioFailureError(
+                msg,
+                code=result.returncode,
                 warns=warns,
             )
 
@@ -155,7 +205,7 @@ class AnsiblePlaybook:
         )
         return result.stdout
 
-    def add_cli_arg(self, name: str, value: str | bool) -> None:
+    def add_cli_arg(self, name: str, value: str | bool) -> None:  # noqa: FBT001
         """Add argument to CLI passed to ansible-playbook.
 
         Args:
