@@ -18,11 +18,11 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Molecule Scenario Module."""
+
 from __future__ import annotations
 
 import fcntl
 import fnmatch
-import logging
 import os
 import shutil
 
@@ -31,16 +31,15 @@ from pathlib import Path
 from time import sleep
 from typing import TYPE_CHECKING
 
-from molecule import scenarios, util
+from molecule import logger, scenarios, util
 from molecule.constants import RC_TIMEOUT
+from molecule.exceptions import MoleculeError
 from molecule.text import checksum
 
 
 if TYPE_CHECKING:
     from molecule.config import Config
-
-
-LOG = logging.getLogger(__name__)
+    from molecule.types import ScenarioResult
 
 
 class Scenario:
@@ -54,6 +53,7 @@ class Scenario:
         """
         self._lock = None
         self.config = config
+        self.results: list[ScenarioResult] = []
         self._setup()
 
     def __repr__(self) -> str:
@@ -67,7 +67,8 @@ class Scenario:
     def _remove_scenario_state_directory(self) -> None:
         """Remove scenario cached disk stored state."""
         directory = str(Path(self.ephemeral_directory).parent)
-        LOG.info("Removing %s", directory)
+        scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+        scenario_log.info("Removing %s", directory)
         shutil.rmtree(directory)
 
     def prune(self) -> None:
@@ -78,7 +79,8 @@ class Scenario:
         files declared as "safe_files" in the ``driver`` configuration
         declared in ``molecule.yml``.
         """
-        LOG.info("Pruning extra files from scenario ephemeral directory")
+        scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+        scenario_log.info("Pruning extra files from scenario ephemeral directory")
 
         safe_files = [
             self.config.state.state_file,
@@ -129,7 +131,7 @@ class Scenario:
             The ephemeral directory for this scenario.
 
         Raises:
-            SystemExit: If lock cannot be acquired before timeout.
+            MoleculeError: If lock cannot be acquired before timeout.
         """
         path: Path
         if "MOLECULE_EPHEMERAL_DIRECTORY" not in os.environ:
@@ -142,8 +144,9 @@ class Scenario:
             path = self.config.runtime.cache_dir / "tmp" / project_scenario_directory
         else:
             path = Path(os.getenv("MOLECULE_EPHEMERAL_DIRECTORY", ""))
+        path.mkdir(parents=True, exist_ok=True)
 
-        if os.environ.get("MOLECULE_PARALLEL", False) and not self._lock:
+        if self.config.is_parallel and not self._lock:
             lock_file = path / ".lock"
             with lock_file.open("w") as self._lock:  # type: ignore[assignment]
                 for i in range(1, 5):
@@ -152,15 +155,35 @@ class Scenario:
                         break
                     except OSError:
                         delay = 30 * i
-                        LOG.warning(
+                        scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+                        scenario_log.warning(
                             "Retrying to acquire lock on %s, waiting for %s seconds",
                             path,
                             delay,
                         )
                         sleep(delay)
                 else:
-                    LOG.warning("Timedout trying to acquire lock on %s", path)
-                    raise SystemExit(RC_TIMEOUT)
+                    scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+                    scenario_log.warning("Timedout trying to acquire lock on %s", path)
+                    raise MoleculeError(code=RC_TIMEOUT)
+
+        return path.absolute().as_posix()
+
+    @cached_property
+    def shared_ephemeral_directory(self) -> str:
+        """Acquire the shared ephemeral directory.
+
+        Returns:
+            The common ephemeral directory for all scenarios.
+        """
+        path: Path
+        if "MOLECULE_EPHEMERAL_DIRECTORY" not in os.environ:
+            project_directory = Path(self.config.project_directory).name
+
+            project_scenario_directory = f"molecule.{checksum(project_directory, 4)}"
+            path = self.config.runtime.cache_dir / "tmp" / project_scenario_directory
+        else:
+            path = Path(os.getenv("MOLECULE_EPHEMERAL_DIRECTORY", ""))
 
         return path.absolute().as_posix()
 
@@ -171,8 +194,12 @@ class Scenario:
         Returns:
             The directory containing the scenario's inventory.
         """
-        path = Path(self.ephemeral_directory) / "inventory"
-        return str(path)
+        if self.config.shared_inventory and not self.config.is_parallel:
+            ephemeral = Path(self.shared_ephemeral_directory)
+        else:
+            ephemeral = Path(self.ephemeral_directory)
+
+        return str(ephemeral / "inventory")
 
     @property
     def check_sequence(self) -> list[str]:
