@@ -38,10 +38,11 @@ from rich.syntax import Syntax
 
 from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
+from molecule.exceptions import MoleculeError
 
 
 if TYPE_CHECKING:
-    from collections.abc import Generator, Iterable, MutableMapping
+    from collections.abc import Generator, Iterable, MutableMapping, Sequence
     from io import TextIOWrapper
     from typing import Any, AnyStr, NoReturn, TypeVar
     from warnings import WarningMessage
@@ -104,7 +105,6 @@ def print_environment_vars(env: dict[str, str] | None) -> None:
             "SHELL REPLAY",
             " ".join([f"{k}={v}" for (k, v) in sorted(combined_env.items())]),
         )
-        print()  # noqa: T201
 
 
 def do_report() -> None:
@@ -128,20 +128,19 @@ def sysexit(code: int = 1) -> NoReturn:
 def sysexit_with_message(
     msg: str,
     code: int = 1,
-    warns: Iterable[WarningMessage] = (),
+    warns: Sequence[WarningMessage] = (),
 ) -> NoReturn:
-    """Exit with an error message.
+    """This method is a lie for compatibility purposes.
 
     Args:
         msg: The message to display.
         code: The return code to exit with.
         warns: A series of warnings to send alongside the message.
-    """
-    LOG.critical(msg, extra={"highlighter": False})
 
-    for warn in warns:
-        LOG.warning(warn.__dict__["message"].args[0])
-    sysexit(code)
+    Raises:
+        MoleculeError: always.
+    """
+    raise MoleculeError(message=msg, code=code, warns=warns)
 
 
 def os_walk(
@@ -206,6 +205,7 @@ def write_file(filename: str | Path, content: str, header: str | None = None) ->
 
     if isinstance(filename, str):
         filename = Path(filename)
+    filename.parent.mkdir(exist_ok=True)
     filename.write_text(content)
 
 
@@ -262,11 +262,15 @@ def safe_load(string: str | TextIOWrapper):  # type: ignore[no-untyped-def]  # n
 
     Returns:
         A dict of the parsed string.
+
+
+    Raises:
+        MoleculeError: when YAML loading fails.
     """
     try:
         return yaml.safe_load(string) or {}
     except yaml.scanner.ScannerError as e:
-        sysexit_with_message(str(e))
+        raise MoleculeError(str(e)) from None
     return {}
 
 
@@ -331,7 +335,7 @@ def filter_verbose_permutation(options: Options) -> Options:
     Returns:
         Dictionary of options without verbose options included.
     """
-    return {k: options[k] for k in options if not re.match("^[v]+$", k)}
+    return {k: options[k] for k in options if not re.match(r"^[v]+$", k)}
 
 
 @overload
@@ -391,10 +395,13 @@ def validate_parallel_cmd_args(cmd_args: CommandArgs) -> None:
 
     Args:
         cmd_args: Arguments to validate.
+
+    Raises:
+        MoleculeError: when incompatible options are present.
     """
     if cmd_args.get("parallel") and cmd_args.get("destroy") == "never":
         msg = 'Combining "--parallel" and "--destroy=never" is not supported'
-        sysexit_with_message(msg)
+        raise MoleculeError(msg)
 
 
 def _parallelize_platforms(
@@ -465,7 +472,7 @@ def lookup_config_file(filename: str) -> str | None:
     return None
 
 
-def boolean(value: bool | AnyStr, *, strict: bool = True) -> bool:
+def boolean(value: bool | AnyStr, *, strict: bool = True) -> bool:  # noqa: FBT001
     """Evaluate any object as boolean matching ansible behavior.
 
     Args:
@@ -480,8 +487,12 @@ def boolean(value: bool | AnyStr, *, strict: bool = True) -> bool:
     """
     # Based on https://github.com/ansible/ansible/blob/devel/lib/ansible/module_utils/parsing/convert_bool.py
 
-    BOOLEANS_TRUE = frozenset(("y", "yes", "on", "1", "true", "t", 1, 1.0, True))  # noqa: N806
-    BOOLEANS_FALSE = frozenset(("n", "no", "off", "0", "false", "f", 0, 0.0, False))  # noqa: N806
+    BOOLEANS_TRUE = frozenset(  # noqa: N806
+        ("y", "yes", "on", "1", "true", "t", 1, 1.0, True),
+    )
+    BOOLEANS_FALSE = frozenset(  # noqa: N806
+        ("n", "no", "off", "0", "false", "f", 0, 0.0, False, ""),
+    )
     BOOLEANS = BOOLEANS_TRUE.union(BOOLEANS_FALSE)  # noqa: N806
 
     if isinstance(value, bool):
@@ -520,7 +531,7 @@ def dict2args(data: MutableMapping[str, str | bool]) -> list[str]:
     return result
 
 
-def bool2args(data: bool | list[str]) -> list[str]:  # noqa: ARG001
+def bool2args(data: bool | list[str]) -> list[str]:  # noqa: ARG001, FBT001
     """Convert a boolean value to command line argument (flag).
 
     Args:
